package org.globus.transfer.reliable.service.test;

import junit.framework.TestCase;

import org.globus.rft.generated.RFTOptionsType;
import org.globus.transfer.reliable.service.UserSubjectUtil;

public class UserSubjectUtilTest extends TestCase {
   
    String subjectName;
    String sourceSubjectName;
    String destSubjectName;
    String nullSubject;
    String emptySubject;
    
    protected void setUp() throws Exception {
        
        super.setUp();
        
        this.subjectName = "/DC=org/DC=globus/CN=Test1";
        this.sourceSubjectName = "/DC=org/DC=globus/CN=Test2";
        this.destSubjectName = "/DC=org/DC=globus/CN=Test3";
        this.nullSubject = null;
        this.emptySubject = " ";
    }
    
    public void testGetUserSubject() {
        
        assertTrue(UserSubjectUtil.getUserSubject(null) == null);
        
        RFTOptionsType options = new RFTOptionsType();
        assertTrue(UserSubjectUtil.getUserSubject(
            options) == null);

        options.setSubjectName(emptySubject);
        assertTrue(UserSubjectUtil.getUserSubject(
            options) == null);
        
        options.setSubjectName(subjectName);
        assertTrue(UserSubjectUtil.getUserSubject(
            options).equals(subjectName));
        
        options.setSourceSubjectName(sourceSubjectName);
        options.setDestinationSubjectName(destSubjectName);
        assertTrue(UserSubjectUtil.getUserSubject(
            options).equals(subjectName));
        
        options.setSubjectName(nullSubject);
        assertTrue(UserSubjectUtil.getUserSubject(
            options).equals(sourceSubjectName));
        
        options.setSubjectName(emptySubject);
        assertTrue(UserSubjectUtil.getUserSubject(
            options).equals(sourceSubjectName));
        
        options.setSourceSubjectName(nullSubject);
        assertTrue(UserSubjectUtil.getUserSubject(
            options).equals(destSubjectName));
        
        options.setSourceSubjectName(emptySubject);
        assertTrue(UserSubjectUtil.getUserSubject(
            options).equals(destSubjectName));
    }
    
    public void testGetSourceUserSubject() {
        
        assertTrue(UserSubjectUtil.getSourceUserSubject(null) == null);
        
        RFTOptionsType options = new RFTOptionsType();
        assertTrue(UserSubjectUtil.getSourceUserSubject(
            options) == null);

        options.setSourceSubjectName(emptySubject);
        assertTrue(UserSubjectUtil.getSourceUserSubject(
            options) == null);

        options.setSubjectName(emptySubject);
        assertTrue(UserSubjectUtil.getSourceUserSubject(
            options) == null);

        options.setDestinationSubjectName(destSubjectName);
        assertTrue(UserSubjectUtil.getSourceUserSubject(
            options) == null);
        
        options.setSourceSubjectName(sourceSubjectName);
        assertTrue(UserSubjectUtil.getSourceUserSubject(
            options).equals(sourceSubjectName));
        
        options.setSubjectName(subjectName);
        assertTrue(UserSubjectUtil.getSourceUserSubject(
            options).equals(sourceSubjectName));
        
        options.setSourceSubjectName(emptySubject);
        assertTrue(UserSubjectUtil.getSourceUserSubject(
            options).equals(subjectName));        
    }
    
    public void testGetDestinationUserSubject() {

        assertTrue(UserSubjectUtil.getDestinationUserSubject(null) == null);

        RFTOptionsType options = new RFTOptionsType();
        assertTrue(UserSubjectUtil.getDestinationUserSubject(
            options) == null);

        options.setDestinationSubjectName(emptySubject);
        assertTrue(UserSubjectUtil.getDestinationUserSubject(
            options) == null);

        options.setSubjectName(emptySubject);
        assertTrue(UserSubjectUtil.getDestinationUserSubject(
            options) == null);

        options.setSourceSubjectName(sourceSubjectName);
        assertTrue(UserSubjectUtil.getDestinationUserSubject(
            options) == null);
        
        options.setDestinationSubjectName(destSubjectName);
        assertTrue(UserSubjectUtil.getDestinationUserSubject(
            options).equals(destSubjectName));
        
        options.setSubjectName(subjectName);
        assertTrue(UserSubjectUtil.getDestinationUserSubject(
            options).equals(destSubjectName));
        
        options.setDestinationSubjectName(emptySubject);
        assertTrue(UserSubjectUtil.getDestinationUserSubject(
            options).equals(subjectName));                
    }
}
