package org.globus.transfer.reliable.service.test.client;

import junit.framework.TestCase;
import javax.xml.namespace.QName;

import org.globus.gsi.GlobusCredential;
import org.globus.gsi.gssapi.GlobusGSSCredentialImpl;
import org.globus.rft.generated.RFTOptionsType;
import org.globus.rft.generated.TotalBytesTransferredResource;
import org.globus.wsrf.impl.SimpleResourcePropertySet;
import org.globus.wsrf.impl.timer.TimerManagerImpl;
import org.globus.transfer.reliable.service.test.TestConfig;
import org.globus.transfer.reliable.service.test.connection.TestUtil;
import org.globus.transfer.reliable.service.RFTConstants;
import org.globus.transfer.reliable.service.cache.ConnectionCacheConfiguration;
import org.globus.transfer.reliable.service.cache.ConnectionManager;
import org.globus.transfer.reliable.service.cache.ConnectionParameter;
import org.globus.transfer.reliable.service.cache.SingleConnectionImpl;
import org.globus.transfer.reliable.service.client.ThirdPartyTransferClient;
import org.globus.transfer.reliable.service.RFTConfiguration;
import org.globus.transfer.reliable.service.database.RFTDatabaseOptions;
import org.globus.transfer.reliable.service.database.ReliableFileTransferDbAdapter;
import org.globus.wsrf.impl.SimpleResourceProperty;
import org.ietf.jgss.GSSCredential;
import commonj.timers.TimerManager;

public class ThirdPartyTransferClientTest extends TestCase {
    
    private TimerManager timerManager;
    private ConnectionManager connManager;
    private RFTOptionsType rftOptions;
    private ThirdPartyTransferClient client;
    private ConnectionParameter params;
    private SimpleResourcePropertySet rpSet;
    private String sourceSubject;
    private String destSubject;
    private GSSCredential credential = null;
    
    protected void setUp() throws Exception {
        super.setUp();
        
        int transferId = -1;
        
        this.rpSet = new SimpleResourcePropertySet(new QName(
            "http://www.globus.org/test","GetPutClientTest"));
        SimpleResourceProperty rp = new SimpleResourceProperty(
            RFTConstants.TOTAL_BYTES_RESOURCE);
        rp.add(new TotalBytesTransferredResource(0));
        rpSet.add(rp);
        
        // setup the timerManager
        this.timerManager = new TimerManagerImpl();

        // setup the connectionManager
        ConnectionCacheConfiguration cacheConfig = new ConnectionCacheConfiguration();
        cacheConfig.setConnectionTimeout(5000);
        cacheConfig.setMaxNumberCachedFDs(10);
        cacheConfig.setSweeperInterval(1000);
        this.connManager =  ConnectionManager.createNewInstance(
            cacheConfig, timerManager);

        this.credential = new GlobusGSSCredentialImpl(
            GlobusCredential.getDefaultCredential(),
            GSSCredential.INITIATE_AND_ACCEPT);

        this.sourceSubject = TestConfig.sourceSubject;
        if (this.sourceSubject == null || this.sourceSubject.trim().equals("")) {
            this.sourceSubject = TestConfig.subject;
        }
        this.destSubject = TestConfig.destinationSubject;
        if (this.destSubject == null || this.destSubject.trim().equals("")) {
            this.destSubject = TestConfig.subject;
        }

        this.rftOptions = new RFTOptionsType();
        // create connection parameter objects for source and destination
        params = new ConnectionParameter(
            TestConfig.sourceHost, TestConfig.sourcePort,
            TestConfig.sourcePath, TestConfig.destinationHost,
            TestConfig.destPort, TestConfig.destPath, TestConfig.subject,
            rftOptions);

        // setup database
        RFTConfiguration rftConfig = new RFTConfiguration();
        rftConfig.setBackOff("1000");
        rftConfig.setMaxActiveAllowed("20"); 

        RFTDatabaseOptions dbOptions = new RFTDatabaseOptions();
        dbOptions.setConnectionString(TestConfig.dbConnectionString);
        dbOptions.setUserName(TestConfig.dbUserName);
        dbOptions.setDriverName(TestConfig.dbDriverName);
        dbOptions.setPassword(TestConfig.dbPassword);
        dbOptions.setMaxActive(TestConfig.dbMaxActive);
        dbOptions.setMaxIdle(TestConfig.dbMaxIdle);
        dbOptions.setMaxWait(TestConfig.dbMaxWait);
        
        // setup the dbAdapter
        ReliableFileTransferDbAdapter.setup(rftConfig, dbOptions);

        // create a client
        this.client = new ThirdPartyTransferClient(
            params, credential, connManager, rpSet, transferId);   
    }
    
    protected void tearDown() throws Exception {
        
        this.connManager.closeAllConnections();
        this.timerManager.stop();
    }

    public void testProcess() {
        try {
            TestUtil.removeFileIfExists(params.getDestinationHost(),
                params.getDestinationPort(), params.getDestinationPath(),
                this.destSubject, this.credential);
            this.client.process();
            if (!TestUtil.removeFileIfExists(params.getDestinationHost(),
                params.getDestinationPort(), params.getDestinationPath(),
                this.destSubject, this.credential)) {
                fail("file didn't exist on destination after transfer");
            }
        } catch (Exception e) {
            fail("testProcess() failed: " + e);
        }
    }
}

