package org.globus.transfer.reliable.service.test.connection;

import java.util.Vector;

import junit.framework.TestCase;
import org.globus.rft.generated.RFTOptionsType;
import org.ietf.jgss.GSSCredential;
import org.globus.gsi.GlobusCredential;
import org.globus.gsi.gssapi.GlobusGSSCredentialImpl;
import org.globus.transfer.reliable.service.test.TestConfig;
import org.globus.transfer.reliable.service.cache.ConnectionParameter;
import org.globus.transfer.reliable.service.cache.MlsdConnectionImpl;
import org.globus.transfer.reliable.service.exception.RftTransientException;

public class MlsdConnectionImplTest extends TestCase {
    
    private MlsdConnectionImpl conn;
    private RFTOptionsType rftOptions;
    private ConnectionParameter params;
    private GSSCredential credential = null;

    public MlsdConnectionImplTest(String name) {
        super(name);
    }

    protected void setUp() throws Exception {
        super.setUp();
        this.credential = new GlobusGSSCredentialImpl(
            GlobusCredential.getDefaultCredential(),
            GSSCredential.INITIATE_AND_ACCEPT);

        rftOptions = new RFTOptionsType();
        rftOptions.setDcau(new Boolean(true));

        // create different connection parameter objects
        params = new ConnectionParameter(
            TestConfig.sourceHost, TestConfig.sourcePort,
            TestConfig.sourcePath, TestConfig.subject,
            rftOptions);
        this.conn = new MlsdConnectionImpl(params,credential,
            TestConfig.subject);
    }

    protected void tearDown() {
        this.conn.closeConnection();
    }

    public void testGetNumberFDs() {
        assertTrue (this.conn.getNumberFDs() == 2);
    }
    
    public void testDoMlsd() {
        try {
            // test doMlsd() on existing file
            String fileName = params.getSourcePath();
            if (!this.conn.exists(fileName)) {
                fail("file " + fileName + " does not exist");
            }
            Vector entries = this.conn.doMlsd(fileName);
            System.out.println("GOT ENTRIES: " + entries);
            
            // test doMlsd() on non-existing file
            fileName = "/some/hopefully/non/existing/file";
            while (this.conn.exists(fileName)) {
                fileName += "X";
            }
            try {
                this.conn.doMlsd(fileName);
                fail("doMlsd() on non-existing file should fail");
            } catch(RftTransientException e) {
            } catch(Exception e) {
                fail("expecting RftTransientException and not "
                    + e.getClass().getName());
            }
        } catch(Exception e) {
            fail("testDoMlsd() failed: " + e);
        }
    }
}
