package org.globus.transfer.reliable.service.test.connection;

import java.io.File;
import org.globus.rft.generated.RFTOptionsType;
import org.globus.transfer.reliable.service.cache.ConnectionParameter;
import org.globus.transfer.reliable.service.cache.SingleConnectionImpl;
import org.globus.transfer.reliable.service.test.TestConfig;
import org.ietf.jgss.GSSCredential;

public class TestUtil {

    public static final String REMOTE_TEST_DIR =
        "/tmp/RFT_CONN_AND_CLIENT_TEST/";
    public static String REMOTE_TEST_FILE = REMOTE_TEST_DIR
        + "test.properties";
    public static String LOCAL_TEST_FILE = System.getProperty("GLOBUS_LOCATION")
        + "/share/globus_wsrf_rft_test/test.properties";

    /**
     * Create a directory using the gridftp connection and transfer
     * a file into it.
     */
    public static void createTestDir(
        String host,
        int port,
        String userSubject,
        GSSCredential credential)
    throws Exception {

        ConnectionParameter params = new ConnectionParameter(
            host, port, REMOTE_TEST_DIR, userSubject, new RFTOptionsType());
        SingleConnectionImpl conn = new SingleConnectionImpl(
            params, credential, userSubject);
        conn.makeDirectory(REMOTE_TEST_DIR);
        if (!conn.exists(REMOTE_TEST_DIR)) {
            throw new Exception("directory " + REMOTE_TEST_DIR + " does not exist");
        }
        if (!conn.exists(REMOTE_TEST_FILE)) {
            conn.put(new File(LOCAL_TEST_FILE), REMOTE_TEST_FILE, false);
        }
        if (!conn.exists(REMOTE_TEST_FILE)) {
            throw new Exception("directory " + REMOTE_TEST_FILE + " does not exist");
        }
    }
    
    /**
     * Remove the test directory.
     */
    public static boolean removeDirIfExists(
        String host,
        int port,
        String dirName,
        String userSubject,
        GSSCredential credential)
    throws Exception {

        boolean dirExisted = false;
        ConnectionParameter params = new ConnectionParameter(
            host, port, dirName, userSubject, new RFTOptionsType());
        SingleConnectionImpl conn = new SingleConnectionImpl(
            params, credential, userSubject);
        conn.setPath(dirName);
        if (conn.exists(dirName)) {
            dirExisted = true;
        }
        conn.deleteDirectory();
        if (conn.exists(REMOTE_TEST_DIR) || conn.exists(REMOTE_TEST_FILE)) {
            throw new Exception ("unable to remove remote test dir and file");
        }
        return dirExisted;
    }

    /** 
     * @return true if the file existed
     * @throws Exception if the file cannot be removed
     */
    public static boolean removeFileIfExists(
        String host,
        int port,
        String fileName,
        String userSubject,
        GSSCredential credential) throws Exception {

        // make sure that the destination file does not exist yet
        SingleConnectionImpl conn = null;
        boolean fileExisted = false;
        
        try {
            ConnectionParameter params = new ConnectionParameter(
                host, port, fileName, userSubject, new RFTOptionsType());
        
            conn = new SingleConnectionImpl(
                params, credential, userSubject);
            if (conn.exists(TestConfig.destPath)) {
                fileExisted = true;
                conn.deleteFile(TestConfig.destPath);
                if (conn.exists(TestConfig.destPath)) {
                    throw new Exception ("can't delete destination file "
                        + fileName);
                }
            }
        } finally {
            if (conn != null) {
                conn.closeConnection();
            }
        }
        return fileExisted;
    }
}
